==> home-made-io-fastmag-sync-m2-0.25.0-3b5902.zip: Model/Constants.php <==
<?php
/*******************************************************************************
 * Created by HOMEMADE.IO SAS.
 * Fastmag Sync  -  Connect Fastmag with your Magento
 *
 * Copyright (C) HOMEMADE.IO SAS, Inc - All Rights Reserved
 *
 * @author    Simon Laubet-Xavier <simon.laubetxavier@home-made.io>
 * @copyright 2020-2021 HOMEMADE.IO SAS
 * @date      2021-09-27
 ******************************************************************************/

namespace Fastmag\Sync\Model;

/**
 * Class Constants
 *
 * Constants container for address
 */
class Constants
{
    /** @var string */
    public const ATTRIBUTE_ADDRESS_ALIAS_CODE = 'fastmag_alias';

    /** @var string */
    public const ATTRIBUTE_ADDRESS_ALIAS_DEFAULT = 'DEFAULT';

    /** @var string */
    public const ATTRIBUTE_GROUP_PRODUCT_DEFAULT_CODE = 'Product Details';

    /** @var string */
    public const ATTRIBUTE_GROUP_PRODUCT_FASTMAG_CODE = 'Fastmag Data';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_PRODUCT_ID_CODE = 'fastmag_product_id';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_EAN13_CODE = 'fastmag_ean13';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_SIZE_CODE = 'fastmag_size';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_COLOR_CODE = 'fastmag_color';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_INTERNAL_COLOR_CODE = 'fastmag_internal_color';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_BRAND_CODE = 'fastmag_brand';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_SUPPLIER_CODE = 'fastmag_supplier';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_FAMILY_CODE = 'fastmag_family';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_SUBFAMILY_CODE = 'fastmag_subfamily';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_SECTION_CODE = 'fastmag_section';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_SEASON_CODE = 'fastmag_season';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_MATERIAL_CODE = 'fastmag_material';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_MODEL_CODE = 'fastmag_model';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_THEME_CODE = 'fastmag_theme';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_WASHING_CODE = 'fastmag_washing';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_CHLORINE_CODE = 'fastmag_chlorine';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_IRONING_CODE = 'fastmag_ironing';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_DRY_CLEANING_CODE = 'fastmag_dry_cleaning';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_DRYING_CODE = 'fastmag_drying';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_WATER_CODE = 'fastmag_water';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_DISCOUNT_RATE_CODE = 'fastmag_discount_rate';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_INVENTORY_SHOP_CODE = 'fastmag_inventory_shop';

    /** @var string */
    public const PRODUCT_FP_SKU = 'FP';

    /** @var string */
    public const PRODUCT_REGVAT_SKU = 'REGVAT';
}

==> home-made-io-fastmag-sync-m2-1.2.1-032b15.zip: Model/Constants.php <==
<?php
/*******************************************************************************
 * Created by HOMEMADE.IO SAS.
 * Fastmag Sync  -  Connect Fastmag with your Magento
 *
 * Copyright (C) HOMEMADE.IO SAS, Inc - All Rights Reserved
 *
 * @author    Simon Laubet-Xavier <simon.laubetxavier@home-made.io>
 * @copyright 2020-2022 HOMEMADE.IO SAS
 * @date      2022-03-18
 ******************************************************************************/

namespace Fastmag\Sync\Model;

/**
 * Class Constants
 *
 * Constants container
 */
class Constants
{
    /** @var string */
    public const ATTRIBUTE_ADDRESS_ALIAS_CODE = 'fastmag_alias';

    /** @var string */
    public const ATTRIBUTE_ADDRESS_ALIAS_DEFAULT = 'DEFAULT';

    /** @var string */
    public const ATTRIBUTE_ADDRESS_ALIAS_HOME = 'HOME';

    /** @var string */
    public const ATTRIBUTE_GROUP_PRODUCT_DEFAULT_CODE = 'Product Details';

    /** @var string */
    public const ATTRIBUTE_GROUP_PRODUCT_FASTMAG_CODE = 'Fastmag Data';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_PRODUCT_ID_CODE = 'fastmag_product_id';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_EAN13_CODE = 'fastmag_ean13';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_SIZE_CODE = 'fastmag_size';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_COLOR_CODE = 'fastmag_color';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_INTERNAL_COLOR_CODE = 'fastmag_internal_color';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_BRAND_CODE = 'fastmag_brand';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_SUPPLIER_CODE = 'fastmag_supplier';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_FAMILY_CODE = 'fastmag_family';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_SUBFAMILY_CODE = 'fastmag_subfamily';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_SECTION_CODE = 'fastmag_section';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_SEASON_CODE = 'fastmag_season';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_MATERIAL_CODE = 'fastmag_material';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_MODEL_CODE = 'fastmag_model';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_THEME_CODE = 'fastmag_theme';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_WASHING_CODE = 'fastmag_washing';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_CHLORINE_CODE = 'fastmag_chlorine';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_IRONING_CODE = 'fastmag_ironing';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_DRY_CLEANING_CODE = 'fastmag_dry_cleaning';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_DRYING_CODE = 'fastmag_drying';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_WATER_CODE = 'fastmag_water';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_DISCOUNT_RATE_CODE = 'fastmag_discount_rate';

    /** @var string */
    public const ATTRIBUTE_PRODUCT_FASTMAG_INVENTORY_SHOP_CODE = 'fastmag_inventory_shop';

    /** @var string */
    public const PRODUCT_FP_SKU = 'FP';

    /** @var string */
    public const PRODUCT_REGVAT_SKU = 'REGVAT';

    /** @var string */
    public const CUSTOMER_DISCOUNT_GROUP_PREFIX = 'Remise Fastmag ';

    /** @var string */
    public const CUSTOMER_GROUPING_GROUP_PREFIX = 'Regroupement Fastmag ';

    /** @var string */
    public const CUSTOMER_GDPR_ACTION_NOTHING = '0';

    /** @var string */
    public const CUSTOMER_GDPR_ACTION_NOTICE = '1';

    /** @var string */
    public const CUSTOMER_GDPR_ACTION_ANONYMIZE = '2';

    /** @var string */
    public const CUSTOMER_GDPR_ACTION_DELETE = '3';
}
